#! /bin/bash


###############################
### Vérifications initiales ###
###############################

function initial()
{
# Variables systeme
release=$(lsb_release -rs)
architecture=$(uname -m)
environnement=$(env | egrep "^DESKTOP_SESSION=")
environnement=${environnement##*=}
liste_paquet=$(dpkg -l)

# Vérification de la présence de gtkdialog
if [[ -z $(egrep "^ii  zenity" <<< "${liste_paquet}") ]]
then
	if [[ ${environnement} == kde ]] && [[ -n $(egrep "^ii  install-package" <<< "${liste_paquet}") ]]
	then
		kdesudo "install-package --install zenity"

	elif [[ ${environnement} == kde ]]
	then
		kdesudo apt-get install zenity

	else
		gksudo apt-get install zenity
	fi
fi

# Vérification de la présence de gtkdialog
if [[ -z $(egrep "^ii  gtkdialog" <<< "${liste_paquet}") ]]
then
	# Dans le cas où la version commence par 10.XX ou sup
	if [[ ${release/%.*} -ge 10 ]]
	then
		zenity --warning --title="GTKDialog" --text="Vous êtes sous une version supérieur ou égale à la 10.04, gtkdialog n'étant plus disponible dans les depots, le script va le télécharger sur launchpad.

Cette fenêtre va se fermer dans 30 secondes." --timeout="30"

		# Téléchargement du deb
		case "${architecture}" in
			*64*) wget http://launchpadlibrarian.net/14540941/gtkdialog_0.7.20-4_amd64.deb -O /tmp/gtkdialog_0.7.20.deb ;;
			*32*) wget http://launchpadlibrarian.net/14537936/gtkdialog_0.7.20-4_i386.deb -O /tmp/gtkdialog_0.7.20.deb ;;
		esac

		# Installation du deb
		sudo dpkg -i /tmp/gtkdialog_0.7.20.deb
		sudo apt-get install -f

		# Suppression du deb
		rm /tmp/gtkdialog_0.7.20.deb

	else
		if [[ ${environnement} == kde ]] && [[ -n $(egrep "^ii  install-package" <<< "${liste_paquet}") ]]
		then
			kdesudo "install-package --install gtkdialog"

		elif [[ ${environnement} == kde ]]
		then
			kdesudo apt-get install gtkdialog

		else
			gksudo apt-get install gtkdialog
		fi
	fi
fi


# Crée le dossir ${HOME}/.local/share/icons/hicolor/48x48/apps s'il n'existe pas
if [[ ! -d "${HOME}/.local/share/icons/hicolor/48x48/apps" ]]
then
	mkdir -p "${HOME}/.local/share/icons/hicolor/48x48/apps"
fi


# Copie des icones dans le dossier ${HOME}/.local/share/icons/hicolor/48x48/apps/
cd "${Dossier_install}"/

for i in zenitor-128.png zenitor.png zenity-scale.png zenity.png zenity-text.png zenitor-update.png zenitor-update-128.png
do
	if [[ ! -e "${HOME}/.local/share/icons/hicolor/48x48/apps/${i}" ]]
	then
		cp ${i} "${HOME}/.local/share/icons/hicolor/48x48/apps/"
	fi
done


# Création d'un raccourci
if [[ ! -e "${HOME}/.local/share/applications/zenitor.desktop" ]]
then
	echo "[Desktop Entry]
Version=${Version}
Encoding=UTF-8
Type=Application
Name=Zenitor
GenericName=Gestionnaire de fenêtre Zenity
Comment=Permet la création, la sauvegarde de fenêtre Zenity
Exec=/opt/Zenitor/zenitor.sh
Icon=/opt/Zenitor/zenitor.png
Terminal=false
Categories=Development;" > "${HOME}/.local/share/applications/zenitor.desktop"
fi


# Pour le fichier config
liste_paquet=$(dpkg -l)

if [[ ! -d "${HOME}/.config/zenitor" ]]
then
	mkdir -p "${HOME}/.config/zenitor"
fi

if [[ -n $(egrep "^ii  gtkdialog" <<< "${liste_paquet}") ]]
then
	echo "gtkdialog : OK" > "${HOME}/.config/zenitor/verif.txt"
else
	echo "gtkdialog : erreur" > "${HOME}/.config/zenitor/verif.txt"
fi

if [[ -n $(egrep "^ii  zenity" <<< "${liste_paquet}") ]]
then
	echo "zenity : OK" >> "${HOME}/.config/zenitor/verif.txt"
else
	echo "zenity : erreur" >> "${HOME}/.config/zenitor/verif.txt"
fi

if [[ -d "${HOME}/.local/share/icons/hicolor/48x48/apps" ]]
then
	echo "dossier icones : OK" >> "${HOME}/.config/zenitor/verif.txt"
else
	echo "dossier icones : erreur" >> "${HOME}/.config/zenitor/verif.txt"
fi

if [[ $(ls ${HOME}/.local/share/icons/hicolor/48x48/apps/zenit* | wc -l) -ge 7 ]]
then
	echo "icones : OK" >> "${HOME}/.config/zenitor/verif.txt"
else
	echo "icones : erreur" >> "${HOME}/.config/zenitor/verif.txt"
fi
}


########################
### Fonctions autres ###
########################

function killlll()
{
for i in Chargement Calendrier Curseur Liste Message Notification Saisie Selection Texte_fichier
do
	if [[ -n $(ps ax | sed '/gtkdialog --program='${i}'$/!d') ]]
	then
		kill -9 $(ps ax | sed '/gtkdialog --program='${i}'$/!d ; s/ \(....\).*/\1/')
	fi
done

if [[ -n $(ps ax | sed '/bash.*zenitor.sh$/!d') ]]
then
	kill -9 $(ps ax | sed '/bash.*zenitor.sh$/!d ; s/ \(....\).*/\1/')
fi
}


function Nouvelle_boite()
{
killlll

# Lancement du script contenant les fenetres GTKDIALOG
bash "${Dossier_install}"/zenitor.sh Nouvelle_boite &
}


function Suppr_slash()
{
sed -i '$s/ \\$//' /tmp/code_fenetre_zenity.txt
}


function Sauvegarde()
{
# Vérifie que le dossier ${HOME}/.config/zenitor existe sinon, il le crée
if [[ ! -d "${HOME}"/.config/zenitor ]]
then
	mkdir -p "${HOME}"/.config/zenitor
fi

# Envoie le code final dans un fichier de sauvegarde
echo "${code_final}" > "${HOME}/.config/zenitor/${nom_sauvegarde}"
}


function Test_code()
{
# Envoie le code final dans le fichier du code afin de pouvoir être testé
echo "${code_final}" > ${argument}
/tmp/exemple_zenity.txt
premier_mot=$(head -1 ${argument})
premier_mot=${premier_mot%% *}

# Vérifie que le début du fichier commence bien par zenity et non par un message d'erreur
if [[ ${premier_mot} == zenity ]]
then
	# Lancement du fichier de code pour voir la fenêtre zenity
	bash ${argument} &
fi
}


function Ajout_code()
{
if [[ ! -d "${HOME}"/.config/zenitor ]]
then
	mkdir -p "${HOME}"/.config/zenitor
fi

echo "${code_final}" > "${HOME}/.config/zenitor/${ajout_code_sauvegarde}"
}


###################################
### Fonctions utiles aux autres ###
###################################


function verif_numerique()
{
# Vérifie que les variables suivantes sont composées uniquement de chiffre
for i in height width timeout $*
do	
	if [[ "${i}" == "nombre_ligne" || "${i}" == "nombre_colonne" ]]
	then
		if [[ -z $(egrep "^[[:digit:]]*$" <<< "${!i}") || ${!i} -eq 0 ]]
		then
			echo "Une erreur est survenue.
La variable ${i} nécessite uniquement 
un nombre et doit être différent de 0.
Cette fonction bloque donc la
création du code." > /tmp/code_fenetre_zenity.txt

			exit
		else
			continue
		fi
	fi
	
	if [[ -n $(egrep "^[[:digit:]]*$" <<< "${!i}") ]] && [[ ${!i} -gt 0 ]]
	then
		# Envoie la variable à la suite de la commande Zenity dans code_fenetre_zenity.txt
		echo "--${i/_/-}=\"${!i}\" \\" >> /tmp/code_fenetre_zenity.txt

	# Vérifie si la variable n'est pas vide, dans ce cas c'est qu'elle contient autre chose que des chiffres
	elif [[ -n ${!i} ]]
	then
		echo "Une erreur est survenue.
La variable ${i} nécessite uniquement 
un nombre et doit être différent de 0.
Cette fonction bloque donc la
création du code." > /tmp/code_fenetre_zenity.txt

		exit
	fi
done
}


function verif_alphanumerique()
{
# Vérifie l'existence des variables suivantes
for i in title text window_icon $*
do
	if [[ -n ${!i} ]]
	then
		# Envoie la variable à la suite de la commande Zenity dans code_fenetre_zenity.txt
		echo "--${i/_/-}=\"${!i}\" \\" >> /tmp/code_fenetre_zenity.txt
	fi
done
}


function cmd_zenity()
{
if [[ "${2}" == "add" ]]
then
	# Ajout de la commande Zenity avec le type de fenêtre dans code_fenetre_zenity.txt
	echo -n "zenity --${1} \\" >> /tmp/code_fenetre_zenity.txt

else
	# Envoie de la commande Zenity avec le type de fenêtre avec création de code_fenetre_zenity.txt
	echo "zenity --${1} \\" > /tmp/code_fenetre_zenity.txt
fi
}


function case_cochee()
{
# Vérifie la validé (true) des variables suivantes
for i in $*
do
	if [[ "${!i}" == "true" ]]
	then
		# Envoie la variable à la suite de la commande Zenity dans code_fenetre_zenity.txt
		echo "--${i/_/-} \\" >> /tmp/code_fenetre_zenity.txt
	fi
done
}


# Commande pour les boutons des fenetres des colonnes, lignes et l'avancement
fin_gtk='		<hbox>
			<button tooltip-text=" Valider les infos ">
				<input file icon="gtk-execute"></input>
				<label>Valider les infos</label>
			</button>

			<button tooltip-text=" Quitter ce super logiciel ?! ">
				<input file icon="gtk-close"></input>
				<label>Quitter</label>
			</button>
		</hbox>
	</vbox>
</window>'


###################################
### Fonctions des boites Zenity ###
###################################


function Calendrier()
{
# Envoie le type de fenêtre Zenity dans code_fenetre_zenity.txt
cmd_zenity calendar

# Vérifie les variables : title text window_icon + les arguments
verif_alphanumerique date_format

# Vérifie la chaine numérique des variables : height width + ldes arguments
verif_numerique year month day

# Suppression du dernier anti slash
Suppr_slash
}


function Texte_fichier()
{
# Envoie de la commande Zenity avec le type de fenêtre
cmd_zenity text-info

# Vérifie les variables : title text window_icon + les arguments
verif_alphanumerique filename

# Vérifie la chaine numérique des variables : height width + ldes arguments
verif_numerique

# Vérifie que la variable est en true
case_cochee editable

# Suppression du dernier anti slash
Suppr_slash
}


function Curseur()
{
# Envoie de la commande zenity avec le type de fenêtre
cmd_zenity scale

# Vérifie les variables : title text window_icon + les arguments
verif_alphanumerique

# Vérifie la chaine numérique des variables : height width + ldes arguments
verif_numerique step value min_value max_value

# Vérifie l'existence d'une valeur pour value si min_value/max_value existe
if [[ -n ${min_value} || -n ${max_value} ]] && [[ -z $(egrep "^[[:digit:]]*$" <<< "${value}") ]]
then
	echo "Une erreur est survenue.
Les informations 'Valeur minimale' / 'Valeur maximale'
nécessitent obligatoirement d'attribuer
une valeur à 'Valeur de départ'." > /tmp/code_fenetre_zenity.txt

	exit

# Vérifie que ${value} est bien compris entre ${min_value} et ${max_value}
elif [[ ${value} -gt ${max_value} || ${value} -lt ${min_value} ]]
then
	echo "Une erreur est survenue.
Votre valeur de base est : ${value}.
Votre valeur minimale est : ${min_value}.
Votre valeur maximale est : ${max_value}.
Il faut que :
 - ${value} >= ${max_value}
 - ${value} <= ${min_value}
Sinon, la valeur de base
perd tout son intérêt." > /tmp/code_fenetre_zenity.txt

	exit

# Vérifie que ${value} est bien compris entre ${min_value} et ${max_value}
elif [[ -n ${step} && -n ${max_value} && $((step + value)) -gt ${max_value} ]]
then
	echo "Une erreur est survenue.
Votre valeur de base est : ${value}.
Votre incrémentation est : ${step}
Votre valeur maximale est : ${max_value}.
Il faut que : ${step} + ${value} <= ${max_value}.
Sinon, cela empêche toute incrémentation
sans dépasser la valeur maximale." > /tmp/code_fenetre_zenity.txt

	exit
fi

# Suppression du dernier anti slash
Suppr_slash
}


function Notification()
{
# Envoie le type de fenêtre Zenity dans code_fenetre_zenity.txt
cmd_zenity notification

# Vérifie les variables : title text window_icon + les arguments
verif_alphanumerique

# Supprime la partie text ne fonctionnant pas pour la notification
sed -i 's/ --text="[^"]*"//' /tmp/code_fenetre_zenity.txt

# Vérifie l'existence de la variable ${action} et l'ajoute à la fin de code_fenetre_zenity.txt
if [[ -n ${action} ]]
then
	echo -n " && ${action}" >> /tmp/code_fenetre_zenity.txt
fi

# Suppression du dernier anti slash
Suppr_slash
}


function Saisie()
{
# Envoie le type de fenêtre Zenity dans code_fenetre_zenity.txt
cmd_zenity entry

# Vérifie les variables : title text window_icon + les arguments
verif_alphanumerique entry_text

# Vérifie la chaine numérique des variables : height width + ldes arguments
verif_numerique

# Vérifie que la variable est en true
case_cochee hide_text

# Si une liste de choix est donnée
if [[ -n ${liste_reponse} && "${hide_text}" == "true" ]]
then
	echo "Vous avez choisis
de crééer une liste déroulante
de choix et de cacher le texte
entré, cela est en contradiction.
Il faut supprimer l'un ou l'autre." > /tmp/code_fenetre_zenity.txt

elif [[ -n ${liste_reponse} && "${hide_text}" == "false" ]]
then
	echo "${liste_reponse}" >> /tmp/code_fenetre_zenity.txt

else
	# Suppression du dernier anti slash
	Suppr_slash
fi
}


function Selection()
{
# Envoie le type de fenêtre Zenity dans code_fenetre_zenity.txt
cmd_zenity file-selection

# Vérifie les variables : title text window_icon + les arguments
verif_alphanumerique filename separator

# Vérifie la chaine numérique des variables : height width + ldes arguments
verif_numerique

# Vérifie que les variables sont en true
case_cochee multiple save directory

# Vérifie que ${multiple} est activé si ${separator} a une valeur
if [[ "${multiple}" != "true" && -n ${separator} ]]
then
	echo "Une erreur est survenue.
Une valeur a été assignée au séparateur or,
la sélection multiple n'a pas été activée.

Il faut donc supprimer le séparateur
ou activer la sélection multiple." > /tmp/code_fenetre_zenity.txt

	exit
fi

# Suppression du dernier anti slash
Suppr_slash
}


function Message()
{
# Envoie le type de fenêtre Zenity dans code_fenetre_zenity.txt
echo -n "zenity " > /tmp/code_fenetre_zenity.txt

# Utilise la seule option qui soit true
case_cochee info error question warning

# Vérifie les variables : title text window_icon + les arguments
verif_alphanumerique

# Vérifie la chaine numérique des variables : height width + les arguments
verif_numerique

# Suppression du dernier anti slash
Suppr_slash
}


function Chargement()
{
# Si un temps d'attente a été donnée on l'envoie dans code_fenetre_zenity.txt
if [[ -n ${sleep_time} ]]
then
	echo "sleep ${sleep_time}" > /tmp/code_fenetre_zenity.txt
else
	rm /tmp/code_fenetre_zenity.txt
fi

# Si un nombre d'étape à été déterminé alors on lance la procédure
if [[ -n $(egrep "^[[:digit:]]*$" <<< "${nombre_etape}") && "${pulsate}" == "false" ]]
then
	# Création d'une fenêtre gtkdialog en fonction du nombre d'étape voulue
export Evolution_chargement='<window title="Zenity Chargement Generator" window_position="1" icon-name="zenitor">
	<vbox>
		'$(if [[ "${pourcentage_automatique}" == "true" ]]
then
	evolution_pourcentage=$(( 100 / nombre_etape ))
fi

for ((i=1; i<=${nombre_etape}; i++))
do
	if [[ "${pourcentage_automatique}" == "true" ]]
	then
		pourcentage=$(( evolution_pourcentage * i ))
	fi

cat << EOF
		<frame Étape ${i}>
			<hbox>
				<text>
					<label>Pourcentage :</label>
				</text>

				<entry tooltip-text=" Le pourcentage est obligatoire. ">
					<default>${pourcentage-0}</default>
					<variable>pourcentage_etape_${i}</variable>
				</entry>
			</hbox>

			<hbox>
				<text>
					<label>Texte :</label>
				</text>

				<entry tooltip-text=" Le texte est facultatif. Pour le point d'\''exclamation, mettre un anti-slash devant. ">
					<variable>texte_etape_${i}</variable>
				</entry>
			</hbox>

			<hbox>
				<text>
					<label>Commande :</label>
				</text>

				<entry tooltip-text=" De base cela sera sleep 1. ">
					<variable>commande_etape_${i}</variable>
				</entry>
			</hbox>
		</frame>
EOF
done
echo "${fin_gtk}")''

	# Récupération des données de gtkdialog dans ${Evolution_chargement}
	textes_et_pourcentages=$(gtkdialog --program Evolution_chargement)

	# On récupère les variables en enlevant tout ce qu'il y a autour des "
	for ((i=1; i<=${nombre_etape}; i++))
	do
		texte=$(grep "texte_etape_${i}=" <<< "${textes_et_pourcentages}")
		texte=${texte#*\"}
		texte=${texte%\"*}

		pourcentage=$(grep "pourcentage_etape_${i}=" <<< "${textes_et_pourcentages}")
		pourcentage=${pourcentage#*\"}
		pourcentage=${pourcentage%\"*}

		commande=$(grep "commande_etape_${i}=" <<< "${textes_et_pourcentages}")
		commande=${commande#*\"}
		commande=${commande%\"*}

		# Si ${pourcentage} n'existe pas, impossible de faire fonctionner l'evolution de la barre
		if [[ -z ${pourcentage} ]]
		then
			echo "Une erreur est survenue.
Aucun pourcentage trouvé,
il est donc impossible de
faire progresser la barre." > /tmp/code_fenetre_zenity.txt

			exit
		fi

		# Si pas de commande renseignée, ça sera sleep 1, envoie des infos pour les différentes étapes dans code_fenetre_zenity.txt
		if [[ -n ${texte} ]]
		then
			echo "echo \"# ${texte}\" ; ${commande:-sleep 1}" >> /tmp/code_fenetre_zenity.txt
			echo "echo \"${pourcentage}\" ; ${commande:-sleep 1}" >> /tmp/code_fenetre_zenity.txt
		else
			echo "echo \"${pourcentage}\" ; ${commande:-sleep 1}" >> /tmp/code_fenetre_zenity.txt
		fi
	done
fi


if [[ -n ${sleep_time} ]] || [[ -n $(egrep "^[[:digit:]]*$" <<< "${nombre_etape}") && "${pulsate}" == "false" ]]
then
	# Ajout des parenthèses nécessaires au sous traitement des commandes
	sed -i '1s/^/(/ ; $s/$/) | /' /tmp/code_fenetre_zenity.txt

	# Reformatage avec echo de code_fenetre_zenity.txt
	echo -n "$(cat /tmp/code_fenetre_zenity.txt)" > /tmp/code_fenetre_zenity.txt
fi

# Envoie le type de fenêtre Zenity dans code_fenetre_zenity.txt
cmd_zenity progress add

# Vérifie les variables : title text window_icon + les arguments
verif_alphanumerique

# Vérifie la chaine numérique des variables : height width + ldes arguments
verif_numerique

# Vérifie que les variables sont en true
case_cochee auto_close pulsate

# Suppression du dernier anti slash
Suppr_slash
}


function Liste()
{
# Envoie le type de fenêtre Zenity dans code_fenetre_zenity.txt, si ${liste} est vide alors la valeur est list
cmd_zenity list

# Utilise la seule option qui soit true
case_cochee multiple radiolist checklist

# Vérifie les variables : title text window_icon + les arguments
verif_alphanumerique hide_column print_column separator

# Vérifie la chaine numérique des variables : height width + les arguments
verif_numerique nombre_colonne nombre_ligne

# Création d'une fenêtre gtkdialog en fonction du nombre de colonne voulue
export Colonnes='<window title="Zenity Liste Generator" window_position="1" icon-name="zenitor">
	<vbox>
		'$(for ((i=1; i<=${nombre_colonne}; i++))
do
cat << EOF
		<frame Colonne ${i}>
			<hbox>
				<text>
					<label>Nom :</label>
				</text>

				<entry tooltip-text=" Titre de la colonne. ">
					<variable>colonne_${i}</variable>
				</entry>
			</hbox>
		</frame>
EOF
done
echo "${fin_gtk}")''

# Vérifie l'existence de la variable ${nombre_colonne} pour lancement de la fenêtre gtk des noms de colonnes
if [[ -n ${nombre_colonne} ]]
then
	# Récupération des données de gtkdialog dans ${Noms_colonnes}
	Noms_colonnes=$(gtkdialog --program Colonnes)

	# On récupère les variables en enlevant tout ce qu'il y a autour des "
	for ((i=1; i<=${nombre_colonne}; i++))
	do
		Nom_colonne=$(grep "colonne_${i}=" <<< "${Noms_colonnes}")
		Nom_colonne=${Nom_colonne#*\"}
		Nom_colonne=${Nom_colonne%\"*}

		# On les ajoute à code_fenetre_zenity.txt
		echo "--column=\"${Nom_colonne}\" \\" >> /tmp/code_fenetre_zenity.txt
	done
fi

# Création d'une fenêtre gtkdialog en fonction du nombre de ligne voulue
export Lignes='<window title="Zenity Liste Generator" window_position="1" icon-name="zenitor">
	<vbox>
		'$(for ((i=1; i<=${nombre_ligne}; i++))
do
cat << EOF
		<frame Ligne ${i}>
			<hbox>
				<text>
					<label>Texte :</label>
				</text>

				<entry tooltip-text=" Dans le cas d'une liste de bouton de choix, 
 vous pouvez indiquer la réponse de base par un TRUE, 
 pour les autres il faut mettre FALSE. 
 Dans le cas de 3 colonnes, il faudrait une réponse du genre : 
 FALSE Carottes râpés Légumes 
 Il est possible de mettre des doubles quote. ">
					<variable>ligne_${i}</variable>
				</entry>
			</hbox>
		</frame>
EOF
done
echo "${fin_gtk}")''

# Vérifie l'existence de la variable ${nombre_ligne} pour lancement de la fenêtre gtk des noms de colonnes
if [[ -n ${nombre_ligne} ]]
then
	# Récupération des données de gtkdialog dans ${Noms_lignes}
	Noms_lignes=$(gtkdialog --program Lignes)

	# On récupère les variables en enlevant tout ce qu'il y a autour des "
	for ((i=1; i<=${nombre_ligne}; i++))
	do
		Nom_ligne=$(grep "ligne_${i}=" <<< "${Noms_lignes}")
		Nom_ligne=${Nom_ligne#*\"}
		Nom_ligne=${Nom_ligne%\"*}

		# On les ajoute à code_fenetre_zenity.txt
		echo "${Nom_ligne} \\" >> /tmp/code_fenetre_zenity.txt
	done

else
	echo "Une erreur est survenue.
Vous n'avez pas indiqué le nombre
de colonne ou de ligne, impossible
de créer une liste." > /tmp/code_fenetre_zenity.txt

	exit
fi

# Suppression du dernier anti slash
Suppr_slash
}


function exemple_fenetre()
{
# Lit la variable ${exemple_fenetre} pour renvoyer l'exemple adapté
case "${exemple_fenetre}" in
	Calendrier*) echo 'zenity --calendar --title="Exemple avec calendrier" \
--text="Veuillez indiquer votre date de naissance. Merci." \
--day="12" --month="10" --year="1984" --date-format="%x"' > /tmp/exemple_zenity.txt ;;
		
	Echelle*) echo 'zenity --scale --title="Température actuelle" \
--text="Veuillez indiquer la température actuelle de votre piece." \
--step="2" --value="15" --min-value="-10" --max-value="40"' > /tmp/exemple_zenity.txt ;;
	
	Affichage*) echo 'zenity --text-info --title="Voici votre code fstab" \
--filename="/etc/fstab" --width="500" --height="400"' > /tmp/exemple_zenity.txt ;;
	
	Liste*) echo 'zenity --list --checklist --title="Perso préféré" \
--text="Indiquez le(s) personnage(s) que vous préférez." \
--column="Oui" --column="Nom" --column="Age" --separator="@" \
FALSE "Bender" "3ans" \
TRUE "Zoidberg" "Mort" \
FALSE "Fry" "32ans" \
TRUE "Leela" "Inconnu" \
FALSE "Hermes" "Peut être 42"' > /tmp/exemple_zenity.txt ;;

	Confirmation*)  echo 'zenity --question --title="Etes vous sûr de vous ?" \
--text="Etes-vous totalement certain d'\''être sûr de faire ça ?
Merci de confirmer.

M.Windows Vista."' > /tmp/exemple_zenity.txt ;;
	
	Notification*)  echo 'zenity --notification --text="Veuillez confirmer la notification." \
&& zenity --info --title="Vous avez validé" \
--text="Vous venez de lancer l'\''action associé à la notification"' > /tmp/exemple_zenity.txt ;;

	Saisie*) echo 'zenity --entry --title="Ville préférée" \
--text="Merci d'\''indiquer votre ville." --entry-text="Caen"' > /tmp/exemple_zenity.txt ;;

	Séléction*) echo 'zenity --file-selection --title="Vérifiez l'\''adresse de vos icones" \
--directory --filename="/usr/share/icons/"' > /tmp/exemple_zenity.txt ;;

	Barre*) echo '(echo "# 1..." ; sleep 1
echo "25" ; sleep 1
echo "# 2......" ; sleep 1
echo "50" ; sleep 1
echo "# 3........." ; sleep 1
echo "75" ; sleep 1
echo "# Soleil \!" ; sleep 1
echo "100" ; sleep 1) | zenity --progress --title="Je compte"' > /tmp/exemple_zenity.txt ;;
esac
}


function Update()
{
# Si on le lance pour la 2éme fois et qu'on est à jour
case "$(head -1 /tmp/update_zenitor.txt)" in

	# Texte pour mise à jour :
	"Cette version est la dernière") echo -e "T'es à jour je te dis !!"  > /tmp/update_zenitor.txt ;;	
	"T'es à jour je te dis !!") echo -e "Azy ! Reste tranquille !\nClic plus !!"  > /tmp/update_zenitor.txt ;;	
	"Azy ! Reste tranquille !") echo -e "Ok, formatage de /home/$USER/\nen cours..."  > /tmp/update_zenitor.txt ;;	
	"Ok, formatage de /home/$USER/") echo -e "T'as eu peur ?!\nFallait pas m'embêter !"  > /tmp/update_zenitor.txt ;;

	# Texte pour connection :	
	"Impossible de se connecter") echo -e "T'es sûr d'être connécté ?"  > /tmp/update_zenitor.txt ;;
	"T'es sûr d'être connécté ?") echo -e "T'acharne pas,\nça vient peut être du serveur."  > /tmp/update_zenitor.txt ;;

	# Vrai mise à jour
	"Mise à jour disponible,") 
		nom_update=$(sed -n "s/.*Zenitor/Zenitor/ ; s/gz.*/gz/p" /tmp/zenitor_version.txt | sort | tail -1)

		# Téléchargement du tar.gz depuis le serveur
		wget -q  http://hizoka.funcenter.fr/linux/zenitor/${nom_update} -O /tmp/${nom_update}

		if [[ ! -e /tmp/${nom_update} ]]
		then
			echo -e "Une erreur est survenue,\nimpossible de télécharger le tar.gz."  > /tmp/update_zenitor.txt
			exit
		fi

		# Décompression du fichier tar.gz dans /opt avec commande kdesudo ou gksudo
		tar -zxf /tmp/${nom_update} -C /tmp/

		# Modification du dossier du logiciel
		sed -i "s@^Dossier_install=.*@Dossier_install=\"${Dossier_install}\"@" /tmp/Zenitor/creation_zenity.sh /tmp/Zenitor/zenitor.sh

		# Copie du dossier au bon endroit
		cp /tmp/Zenitor/* "${Dossier_install}"

		# Suppression du fichier tar.gz
		rm /tmp/${nom_update} 

		# Lancement du script contenant les fenetres GTKDIALOG
		bash "${Dossier_install}"/zenitor.sh & ;;

	# si c'est le 1er lancement ou qu'on est pas à jour http://doc.ubuntu-fr.org/zenety_generator
	*)
		# Version installée : ${Version}

		# Version dispo sur mon serveur
		wget -q http://hizoka.funcenter.fr/linux/zenitor/ -O /tmp/zenitor_version.txt
		v_net=$(sed -n "s/.*Zenitor_// ; s/.tar.gz.*//p" /tmp/zenitor_version.txt | sort | tail -1)

		if [[ -z ${v_net} ]]
		then
			echo -e "Impossible de se connecter\nau serveur..." > /tmp/update_zenitor.txt
			
		elif [[ ${Version} = ${v_net} ]]
		then
			echo -e "Cette version est la dernière\ndisponible." > /tmp/update_zenitor.txt

		elif [[ ${Version} != ${v_net} ]]
		then
			echo -e "Mise à jour disponible,\nrecliquez pour mettre à jour.\n\nCela relancera le logiciel." > /tmp/update_zenitor.txt
		fi ;;
esac
}


#########################################################
### Lancement de la fonction ayant le même nom que $1 ###
#########################################################

if [[ -n ${2} ]]
then
	argument="${2}"
fi

${1}


exit


